<?php
/*
Plugin Name: WP FaceBook Quiz Creator
Plugin URI: http://AppWholesaler.com/
Description: With WP FaceBook Quiz Creator, you can easily create fun, entertaining FaceBook quizzes with just a few clicks of your mouse. By using this useful and effective plugin, you’re giving your visitors the chance to challenge themselves by solving quizzes that will keep them entertained (so this way they will spend more time in your site.) You can also use it to grow your traffic using a series of trivia quizzes with topics related to your business/website.
Version: 1.0
Author: Stanley Jackson - App Wholesaler
Author URI: http://AppWholesaler.com/
*/

/*
    LICENSE: This source file to be part of a system developed by InstaPRoduct. 
    All copyrights use this file and the code in it owned by InstaPRoduct. 
    It is strictly forbidden to use, copy, modify or distribute this file and 
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPQUIZ_TITLE', 'WP FaceBook Quiz Creator' );
define( 'IPQUIZ_FILE', __FILE__ );
define( 'IPQUIZ_PATH', plugin_dir_path( __FILE__ ) );
define( 'IPQUIZ_BASE_URL', plugin_dir_url( __FILE__ ) );

require_once( plugin_dir_path( __FILE__ ) . "includes/setting.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/db.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/model.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/ajax.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/admin.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/widget.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/factory.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/factory-promo.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/statistic.php" ); 

 
/**
 * Class for generate notification
 */
if ( ! class_exists( 'IPQuiz' )) {

    class IPQuiz
    {
        /**
         * Setup Plugin
         */
        public static function setup()
        {
            $hook = strtolower( IPQUIZ_TITLE );
            $hook = preg_replace( '@[^a-zA-Z0-9\-]@', '-', $hook );
            
            //Install Plugin
            register_activation_hook( __FILE__, array( __CLASS__, 'install' ) );
            
            //Rewrite Handler
            add_action( 'init', array( __CLASS__, 'rewriteFlush' ) );
            add_action( 'pre_get_posts', array( __CLASS__, 'init' ) );
            
            //Render fb page
            add_action( 'template_redirect', array( __CLASS__, 'renderFb' ) );
            
            //Hook for plugin loaded
            add_action( 'plugins_loaded', array( __CLASS__, 'updateDb' ) );
            
            //Plugin init
            add_action( 'admin_init', array( __CLASS__, 'adminInit' ) );
            
            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'addAdminMenu' ) );
            
            //Register Widget
            add_action( 'widgets_init', array( __CLASS__, 'widget' ));
            
            // Add meta box option
            add_action( 'add_meta_boxes', array( __CLASS__, 'addMetaBox' ) );
            add_action( 'save_post', array( __CLASS__, 'savePagePromo' ) );
            
            //Add Editor Button
            add_action( 'admin_init', array( __CLASS__, 'addEditorButton' ) );
            
            //Add Editor Dialog
            add_action( 'tiny_mce_preload_dialogs', array( __CLASS__, 'createEditor' ) );
            add_action( 'after_wp_tiny_mce', array( __CLASS__, 'createEditor' ) );
            
            //Add Shortcode
            add_shortcode( 'ez-quiz', array( __CLASS__, 'shortcode' ) );
            
            //Add admin style & script
            add_action( 'admin_print_styles', array( __CLASS__, 'printAdminStyle' ), 1000 );
            add_action( 'admin_print_scripts', array( __CLASS__, 'printGlobalAdminScript' ), 900 );
            add_action( 'admin_print_scripts-toplevel_page_ipquiz', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipquiz-add', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipquiz-promo', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipquiz-setting', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipquiz-stats', array( __CLASS__, 'printAdminScript' ), 1000 );
            
            //Add popup to site
            add_action( 'wp_footer', array( __CLASS__, 'factory' ) );
            
            //Front style & script
            add_action('wp_head', array( __CLASS__, 'printStyle' ) );
            
            if ( ! is_admin() ) {
                add_action( "wp_enqueue_scripts", array( __CLASS__, 'libScript' ), 11 );
                add_action('wp_enqueue_scripts', array( __CLASS__, 'printScript' ), 12 );
            } 
        }
        
        /**
         * Install plugin
         *
         * @return void
         */
        public static function install()
        {
            //Install DB
            $db = new IPQuiz_Db();
            $db->install();
            
            //Rewrite
            self::rewriteInit();
            flush_rewrite_rules();
        }
        
        /**
         * Init request
         *
         * @return void
         */
        public static function init( $query )
        {
            $q = $query->query;
            if ( isset( $q['ipquiz'] ) && isset( $q['ipquizname'] )) {
                $query->query_vars['post_type'] = 'ipquiz-item';
                $query->query_vars['name']      = $q['ipquizname'];
                $query->query_vars['pagename']  = $q['ipquizname'];
                $query->query['pagename']       = $q['ipquizname'];
            } 
        }
        
        /**
         * Init rewrite rule
         *
         * @return void
         */
        public static function rewriteInit()
        {
            //Quiz fb rewrite
            $base = 'ipquiz/fb';
            add_rewrite_rule(
                $base . '/([^/]+)/?$',
                'index.php?ipquiz=1&ipquizname=$matches[1]',
                'top'
            );
            add_rewrite_tag( '%ipquizname%', '([a-zA-Z0-9\_])');
            add_rewrite_tag( '%ipquizid%', '([0-9])');
            add_rewrite_tag( '%ipquiz%', '([1])');
        }
        
        /**
         * Flush rewrite rule
         *
         * @return void
         */
        public function rewriteFlush()
        {
            self::rewriteInit();
        }
        
        /**
         * Render fb page
         *
         * @return void
         */
        public function renderFb()
        {
            global $wp_query, $user_ID;
            
            if ( ! empty( $wp_query->query['ipquizid'] ) ) 
            {
                $quizId = absint( $wp_query->query['ipquizid'] );
                if ( $quiz = get_post( $quizId )) 
                {
                    $template = new IPQuiz_Factory();
                    $template->facebook( $quiz );
                    exit();
                }
            }
        }
        
        /**
         * Update Db
         *
         * @return void
         */
        public static function updateDb()
        {
            $db = new IPQuiz_Db();
            $db->update();
        }
        
        /**
         * Admin Init
         *
         * @return void
         */
        public static function adminInit()
        {
            global $wp_roles;
            
            /** 
             * Register Roles
             */
            // Add capability for administrator
            $role = get_role( 'administrator' );
            $role->add_cap( 'ipquiz_manage' );
            
            $wp_roles->reinit();
            
            /**
             * Ajax handler
             **/
            $ajax = new IPQuiz_Ajax();
            $ajax->exec();
        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public static function addAdminMenu()
        {
            add_menu_page( 
                IPQUIZ_TITLE, 
                IPQUIZ_TITLE, 
                'ipquiz_manage', 
                'ipquiz',
                array( __CLASS__, 'admin' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'ipquiz',
                __( 'All Quizes', 'ipquiz' ), 
                __( 'All Quizes', 'ipquiz' ), 
                'ipquiz_manage', 
                'ipquiz',
                array( __CLASS__, 'admin' )
            );
            add_submenu_page( 
                'ipquiz',
                __( 'Add Quiz', 'ipquiz' ), 
                __( 'Add Quiz', 'ipquiz' ), 
                'ipquiz_manage', 
                'ipquiz-add',
                array( __CLASS__, 'adminAdd' )
            );
            add_submenu_page( 
                'ipquiz',
                __( 'Quiz Promo', 'ipquiz' ), 
                __( 'Quiz Promo', 'ipquiz' ), 
                'ipquiz_manage', 
                'ipquiz-promo',
                array( __CLASS__, 'adminPromo' )
            );
            add_submenu_page( 
                'ipquiz',
                __( 'Statistic', 'ipquiz' ), 
                __( 'Statistic', 'ipquiz' ), 
                'ipquiz_manage', 
                'ipquiz-stats',
                array( __CLASS__, 'adminStats' )
            );
            add_submenu_page( 
                'ipquiz',
                __( 'Settings', 'ipquiz' ), 
                __( 'Settings', 'ipquiz' ), 
                'ipquiz_manage', 
                'ipquiz-setting',
                array( __CLASS__, 'adminSetting' )
            );
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public static function admin()
        {
            $display = new IPQuiz_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->edit();
            } elseif ( ! empty( $_GET['action'] ) && $_GET['action'] == 'stat' ) {
                $display->stat();
            } else {
                $display->index();
            }
        }
        
        /**
         * Content for administrator add quiz page
         *
         * @return void
         */
        public static function adminAdd()
        {
            $display = new IPQuiz_Admin();
            $display->add();
        }
        
        /**
         * Content for administrator quiz promo page
         *
         * @return void
         */
        public static function adminPromo()
        {
            $display = new IPQuiz_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->promoEdit();
            } elseif ( ! empty( $_GET['action'] ) && $_GET['action'] == 'add' ) {
                $display->promoAdd();
            } else {
                $display->promo();
            }
        }
        
        /**
         * Content for administrator setting page
         *
         * @return void
         */
        public static function adminSetting()
        {
            $display = new IPQuiz_Admin();
            $display->setting();
        }
        
        /**
         * Content for administrator statistic page
         *
         * @return void
         */
        public static function adminStats()
        {
            $display = new IPQuiz_Statistic();
            $display->admin();
        }
        
        /**
         * Main method for create quiz button
         *
         * @param  array  $atts
         * @param  string $content
         * @return string
         */
        public static function shortcode( $atts, $content = '')
        {
            $factory = new IPQuiz_Factory();
            return $factory->shortcode( $atts, $content );
        }
        
        /**
         * Popup factory
         *
         * @return void
         */
        public static function factory()
        {
            //Factory quiz promo
            $factory = new IPQuiz_FactoryPromo();
            $factory->render();
        }
        
        /**
         * Widget innit
         */
        public static function widget() 
        {
            register_widget( 'IPQuiz_Widget' );
        }
        
        /**
         * Add administrator meta box for post/page
         *
         * @return void
         */
        public static function addMetaBox()
        {
            $screens = array( 'post', 'page' );
            foreach ($screens as $screen) {
                add_meta_box(
                    'ipquiz_metabox',
                    __( 'Quiz Promo Setting', 'ipquiz' ),
                    array( __CLASS__, 'metaBoxContent' ),
                    $screen,
                    'normal',
                    'high'
                );
            }
        }
        
        /**
         * Content for administrator meta box
         *
         * @return void
         */
        public static function metaBoxContent( $post )
        {
            $display = new IPQuiz_Admin();
            $display->metaBox( $post );
        }
        
        /**
         * Save page/post promo setting
         *
         * @return void
         */
        public static function savePagePromo( $post_id )
        {
            return true;
        }
         
        /**
         * Hook function for add button to editor
         *
         * @return void
         */
        public static function addEditorButton() 
        {
            if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') ) {
                return;
            }
            if ( get_user_option('rich_editing') == 'true') {
                add_filter( 'mce_external_plugins', array( __CLASS__, 'addTinymcePlugin' ));
                add_filter( 'mce_buttons', array( __CLASS__, 'registerTinymceButton' ));
            }
        }

        /**
         * Register button to TinyMce system
         *
         * @param  array $button
         * @return void
         */
        public static function registerTinymceButton( $buttons ) 
        {
           array_push($buttons, "|", "ipquizsc");
           return $buttons;
        }

        /**
         * Register TinyMce plugin
         *
         * @param  array $plugin_array
         * @return void
         */
        public static function addTinymcePlugin( $plugin_array ) 
        {
           $plugin_array['ipquizsc'] = plugin_dir_url( __FILE__ ) . 'js/editor_plugin.js';
           return $plugin_array;
        }
        
        /**
         * Content editor dialog
         *
         * @return void
         */
        public static function createEditor()
        {
            $display = new IPQuiz_Admin();
            $display->editor();
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function printAdminStyle()
        {
            wp_deregister_style('font-awesome-style');
            wp_register_style('font-awesome-style', '//netdna.bootstrapcdn.com/font-awesome/4.0.3/css/font-awesome.css', false, null);
            wp_enqueue_style('font-awesome-style');
            
            wp_deregister_style('insta-admin-style');
            wp_register_style('insta-admin-style', plugin_dir_url( __FILE__ ) . 'css/ipadmin.css', false, null);
            wp_enqueue_style('insta-admin-style');
            
            wp_deregister_style('ipquiz-admin-style');
            wp_register_style('ipquiz-admin-style', plugin_dir_url( __FILE__ ) . 'css/admin.css', false, null);
            wp_enqueue_style('ipquiz-admin-style');
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public static function printAdminScript($hook)
        {
            wp_deregister_script('insta-admin-script');
            wp_enqueue_script(
                'insta-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/ipadmin.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('ipquiz-admin-script');
            wp_enqueue_script(
                'ipquiz-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/admin.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('ipadmin-jquery-json');
            wp_enqueue_script(
                'ipadmin-jquery-json',
                plugin_dir_url( __FILE__ ) . 'js/jquery.json-2.4.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print Global Admin Script
         *
         * @return void
         */
        public static function printGlobalAdminScript($hook)
        {
            wp_deregister_script('ipquiz-admin-global-script');
            wp_enqueue_script(
                'ipquiz-admin-global-script',
                plugin_dir_url( __FILE__ ) . 'js/admin-global.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print style
         *
         * @return void
         */
        public static function printStyle()
        {
            wp_deregister_style('font-awesome-style');
            wp_register_style('font-awesome-style', '//netdna.bootstrapcdn.com/font-awesome/4.0.3/css/font-awesome.css', false, null);
            wp_enqueue_style('font-awesome-style');
        ?>
            <script type="text/javascript">
                var ajaxurl = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
                var ipquiz_share_msg = "<?php echo get_option( 'ipquiz_share_message' ); ?>";
                var ipquiz_invite_msg = "<?php echo get_option( 'ipquiz_invite_message' ); ?>";
            </script>
            <script type="text/javascript" src="<?php echo plugin_dir_url( __FILE__ ) ?>js/jquery.json-2.4.min.js"></script>
            <script type="text/javascript" src="<?php echo plugin_dir_url( __FILE__ ) ?>js/fb-script.js"></script>
            <link href='http://fonts.googleapis.com/css?family=Lato:300,400,700,300italic,400italic,700italic|Oregano' rel='stylesheet' type='text/css'>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/style.css" rel="stylesheet">
        <?php
        }

        /**
         * Print script
         *
         * @return void
         */
        public static function printScript()
        {
            wp_deregister_script('ipquiz-jcanvas');
            wp_enqueue_script(
                'ipquizp-jcanvas',
                plugin_dir_url( __FILE__ ) . 'js/jcanvas.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('ipquiz-front-script');
            wp_enqueue_script(
                'ipquizp-front-script',
                plugin_dir_url( __FILE__ ) . 'js/script.js',
                array( 'jquery' ),
                1,
                true
            );
        }
        
        /**
         * Lib script
         *
         * @return void
         */
        public static function libScript()
        {
            wp_enqueue_script('jquery');
            
            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');
        }
    }

}
//Run plugin
IPQuiz::setup();
?>